@@ -24,9 +24,9 @@
 #include <assert.h>
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <ktempfile.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdetempfile.h>
 #include <kstandarddirs.h>
 #include <tqfile.h>
 #include <tqtextstream.h>
@@ -301,7 +301,7 @@ int GpsimProcessor::operandLiteral( unsigned address )
 
 GpsimProcessor::ProgramFileValidity GpsimProcessor::isValidProgramFile( const TQString & programFile )
 {
-	if ( !KStandardDirs::exists(programFile) )
+	if ( !TDEStandardDirs::exists(programFile) )
 		return DoesntExist;
 	
 	TQString extension = programFile.right( programFile.length() - programFile.findRev('.') - 1 ).lower();
@@ -736,7 +736,13 @@ RegisterSet::RegisterSet( pic_processor * picProcessor )
 		m_nameToRegisterMap[ info->name() ] = info;
 	}
 	
-	RegisterInfo * info = new RegisterInfo( picProcessor->W );
+	RegisterInfo * info = new RegisterInfo(
+#ifdef GPSIM_0_27_0
+		picProcessor->Wreg
+#else
+		picProcessor->W
+#endif
+		);
 	m_registers.append( info );
 	m_nameToRegisterMap[ info->name() ] = info;
 }
