@@ -20,10 +20,10 @@
 #include "pinmapping.h"
 
 #include <kdebug.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <kmessagebox.h> 
-#include <ktempfile.h>
+#include <tdeio/netaccess.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h> 
+#include <tdetempfile.h>
 #include <tqbitarray.h>
 #include <tqfile.h>
 
@@ -98,11 +98,11 @@ void ItemDocumentData::reset()
 bool ItemDocumentData::loadData( const KURL &url )
 {
 	TQString target;
-	if ( !KIO::NetAccess::download( url, target, 0l ) )
+	if ( !TDEIO::NetAccess::download( url, target, 0l ) )
 	{
 		// If the file could not be downloaded, for example does not
 		// exist on disk, NetAccess will tell us what error to use
-		KMessageBox::error( 0l, KIO::NetAccess::lastErrorString() );
+		KMessageBox::error( 0l, TDEIO::NetAccess::lastErrorString() );
 		
 		return false;
 	}
@@ -194,9 +194,9 @@ bool ItemDocumentData::saveData( const KURL &url )
 		*file.textStream() << toXML();
 		file.close();
 		
-		if ( !KIO::NetAccess::upload( file.name(), url, 0l ) )
+		if ( !TDEIO::NetAccess::upload( file.name(), url, 0l ) )
 		{
-			KMessageBox::error( 0l, KIO::NetAccess::lastErrorString() );
+			KMessageBox::error( 0l, TDEIO::NetAccess::lastErrorString() );
 			return false;
 		}
 	}
