@@ -25,7 +25,7 @@
 #include <klineedit.h>
 #include <knuminput.h>
 #include <kurlrequester.h>
-#include <ktoolbar.h>
+#include <tdetoolbar.h>
 #include <tqapplication.h>
 #include <tqlabel.h>
 #include <tqcheckbox.h>
@@ -156,7 +156,7 @@ void ItemInterface::slotUpdateItemInterface()
 	// Update item editor toolbar
 	if ( ItemView * itemView = dynamic_cast<ItemView*>(p_cvb->activeView()) )
 	{
-		if ( m_pActiveItemEditorToolBar = dynamic_cast<KToolBar*>(p_ktechlab->factory()->container("itemEditorTB",itemView)) )
+		if ( m_pActiveItemEditorToolBar = dynamic_cast<TDEToolBar*>(p_ktechlab->factory()->container("itemEditorTB",itemView)) )
 		{
 			m_pActiveItemEditorToolBar->setFullSize( true );
 			TQWidget * widget = configWidget();
